Crate miden_node_tracing

Crate miden_node_tracing 

Miden node tracing conventions and OpenTelemetry integration.

Modules

field
Span and Event key-value data.
grpc
panic
spawn

Macros

debug
Emits a debug-level event.
enabled
Checks whether a span or event is enabled based on the provided metadata.
error
Emits an error-level event with a complete error report.
info
Emits an info-level event.
info_span
Constructs a span at the info level.
miden_span_record
Records canonical attributes on the current miden_instrument span.
trace
Emits a trace-level event.
warn
Emits a warning-level event.

Structs

Level
Describes the level of verbosity of a span or event.
OtelGuard
A guard that shuts down the tracer provider when dropped. This ensures that the logs are flushed to the exporter before the program exits.
ResourceConfig
Default OpenTelemetry resource attributes for this process.
Span
A handle representing a span, with the capability to enter the span if it exists.
TracingConfig
Tracing subscriber configuration.

Enums

OpenTelemetry
Configures setup_tracing to enable or disable the open-telemetry exporter.

Traits

ErrorReport
Extends errors with a stable string representation of their source chain.
ErrorSpanExt
Extension helper for marking the current OpenTelemetry span as failed.
Instrument
Attaches spans to a std::future::Future.
RecordAttribute
Converts a value into its canonical tracing attribute representation.
Value
A field value of an erased type.

Functions

setup_tracing
Initializes tracing to stdout and optionally an open-telemetry exporter.
setup_tracing_with_config
Initializes tracing from explicit stdout and OpenTelemetry filter configuration.

Attribute Macros

miden_instrument
Instruments a function using canonical tracing attributes.