Miden node tracing conventions and OpenTelemetry integration.
Modules
Macros
- debug
- Emits a debug-level event.
- enabled
- Checks whether a span or event is enabled based on the provided metadata.
- error
- Emits an error-level event with a complete error report.
- info
- Emits an info-level event.
- info_
span - Constructs a span at the info level.
- miden_
span_ record - Records canonical attributes on the current
miden_instrumentspan. - trace
- Emits a trace-level event.
- warn
- Emits a warning-level event.
Structs
- Level
- Describes the level of verbosity of a span or event.
- Otel
Guard - A guard that shuts down the tracer provider when dropped. This ensures that the logs are flushed to the exporter before the program exits.
- Resource
Config - Default OpenTelemetry resource attributes for this process.
- Span
- A handle representing a span, with the capability to enter the span if it exists.
- Tracing
Config - Tracing subscriber configuration.
Enums
- Open
Telemetry - Configures
setup_tracingto enable or disable the open-telemetry exporter.
Traits
- Error
Report - Extends errors with a stable string representation of their source chain.
- Error
Span Ext - Extension helper for marking the current OpenTelemetry span as failed.
- Instrument
- Attaches spans to a
std::future::Future. - Record
Attribute - Converts a value into its canonical tracing attribute representation.
- Value
- A field value of an erased type.
Functions
- setup_
tracing - Initializes tracing to stdout and optionally an open-telemetry exporter.
- setup_
tracing_ with_ config - Initializes tracing from explicit stdout and OpenTelemetry filter configuration.
Attribute Macros
- miden_
instrument - Instruments a function using canonical tracing attributes.